# cookiebutter 🍪🧈

[![PyPI](https://img.shields.io/pypi/v/cookiebutter)](https://pypi.org/project/cookiebutter/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cookiebutter)](https://pypi.org/project/cookiebutter/)
[![PyPI License](https://img.shields.io/pypi/l/cookiebutter)](https://pypi.org/project/cookiebutter/)
[![Code Style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black/)

Cookiecutter, but all buttered up.  
Use cookiecutter with yaml files, or even with python files.
